==> ctxextensions_3.1.2004052301.orig.tar.gz: ctxextensions-3.1.2004052301/chrome/content/ctxextensions/default/default.js <==
pref("ctxextensions.enable.debug_mode", false);
pref("ctxextensions.enable.expert_prefs", false);
pref("ctxextensions.enable.nsIXULTemplateBuilder", false);
pref("ctxextensions.enable.cite_as_href", false);
pref("ctxextensions.enable.popupToTop_TL", true);
pref("ctxextensions.enable.popupToTop_TR", false);
pref("ctxextensions.enable.popupToTop_BL", false);
pref("ctxextensions.enable.popupToTop_BR", false);
pref("ctxextensions.enable.popupToEnd_TL", false);
pref("ctxextensions.enable.popupToEnd_TR", false);
pref("ctxextensions.enable.popupToEnd_BL", true);
pref("ctxextensions.enable.popupToEnd_BR", false);
pref("ctxextensions.enable.getLinks_collectOnClick", false);
pref("ctxextensions.enable.navigations_advanced", false);
pref("ctxextensions.enable.navigations_collectLinks", false);
pref("ctxextensions.enable.navigations_submenu", true);

pref("ctxextensions.styleManager.userContentCSS_reload_alert", true);

pref("ctxextensions.scan_navigations_in_background.enable",   true);
pref("ctxextensions.scan_navigations_in_background.interval", 1000);
pref("ctxextensions.scan_outline_in_background.enable",       true);
pref("ctxextensions.scan_outline_in_background.interval",     1000);

pref("ctxextensions.JSPanel.page.number", 1);
pref("ctxextensions.JSPanel.page.last",   0);

pref("ctxextensions.override.datasource_path", "");
pref("ctxextensions.override.mailer.path", "");
pref("ctxextensions.override.mailer.options", "-to \"%to\" -subject \"%subject\"");
pref("ctxextensions.override.mailer.charset", "UTF-8");
pref("ctxextensions.override.mailer.webmail.enable", false);
pref("ctxextensions.override.mailer.webmail.usetab", true);
pref("ctxextensions.override.mailer.webmail.path", "http://foobar.com/?mailto=%to&subject=%subject");
pref("ctxextensions.override.source_viewer.path", "");
pref("ctxextensions.override.source_viewer.options", "%s");
pref("ctxextensions.override.CSSEditor.path", "");
pref("ctxextensions.override.CSSEditor.options", "%s");

// show in the context menu
pref("ctxextensions.show_item.context.bookmarks", true);
pref("ctxextensions.show_item.context.customScripts", true);
pref("ctxextensions.show_item.context.execApps", true);
pref("ctxextensions.show_item.context.extensions", true);
pref("ctxextensions.show_item.context.getLinks", true);
pref("ctxextensions.show_item.context.go", true);
pref("ctxextensions.show_item.context.help", true);
pref("ctxextensions.show_item.context.JSPanel", true);
pref("ctxextensions.show_item.context.navigations", true);
pref("ctxextensions.show_item.context.nextHeading", true);
pref("ctxextensions.show_item.context.openCiteForEdit", true);
pref("ctxextensions.show_item.context.openCiteForQuote", true);
pref("ctxextensions.show_item.context.openLongdesc", true);
pref("ctxextensions.show_item.context.openSelectionAsURI", true);
pref("ctxextensions.show_item.context.outline", true);
pref("ctxextensions.show_item.context.pref", true);
pref("ctxextensions.show_item.context.prevHeading", true);
pref("ctxextensions.show_item.context.sendStr", true);
pref("ctxextensions.show_item.context.sendURI", true);
pref("ctxextensions.show_item.context.showAll", true);
pref("ctxextensions.show_item.context.showCites", false);
pref("ctxextensions.show_item.context.showComments", false);
pref("ctxextensions.show_item.context.showEvents", false);
pref("ctxextensions.show_item.context.showIDs", false);
pref("ctxextensions.show_item.context.showLinks", false);
pref("ctxextensions.show_item.context.showTitles", false);
pref("ctxextensions.show_item.context.styleSheets", true);
pref("ctxextensions.show_item.context.up", true);

pref("ctxextensions.show_item.context.sep_exec", true);
pref("ctxextensions.show_item.context.sep_extensions", true);
pref("ctxextensions.show_item.context.sep_extensionsAbout", true);
pref("ctxextensions.show_item.context.sep_extensionsMisc", true);
pref("ctxextensions.show_item.context.sep_extensionsOpen", true);
pref("ctxextensions.show_item.context.sep_navigations", true);
pref("ctxextensions.show_item.context.sep_send", true);
pref("ctxextensions.show_item.context.sep_show", true);

// show in submenu
pref("ctxextensions.submenu.context.customScripts", true);
pref("ctxextensions.submenu.context.execApps", true);
pref("ctxextensions.submenu.context.getLinks", true);
pref("ctxextensions.submenu.context.help", true);
pref("ctxextensions.submenu.context.JSPanel", true);
pref("ctxextensions.submenu.context.navigations", true);
pref("ctxextensions.submenu.context.nextHeading", true);
pref("ctxextensions.submenu.context.openCiteForEdit", true);
pref("ctxextensions.submenu.context.openCiteForQuote", true);
pref("ctxextensions.submenu.context.openLongdesc", true);
pref("ctxextensions.submenu.context.openSelectionAsURI", true);
pref("ctxextensions.submenu.context.outline", true);
pref("ctxextensions.submenu.context.pref", true);
pref("ctxextensions.submenu.context.prevHeading", true);
pref("ctxextensions.submenu.context.sendStr", true);
pref("ctxextensions.submenu.context.sendURI", true);
pref("ctxextensions.submenu.context.showAll", true);
pref("ctxextensions.submenu.context.showCites", true);
pref("ctxextensions.submenu.context.showComments", true);
pref("ctxextensions.submenu.context.showEvents", true);
pref("ctxextensions.submenu.context.showIDs", true);
pref("ctxextensions.submenu.context.showLinks", true);
pref("ctxextensions.submenu.context.showTitles", true);
pref("ctxextensions.submenu.context.styleSheets", true);

pref("ctxextensions.submenu.menubar.customScripts", true);
pref("ctxextensions.submenu.menubar.execApps", true);
pref("ctxextensions.submenu.menubar.getLinks", true);
pref("ctxextensions.submenu.menubar.JSPanel", true);
pref("ctxextensions.submenu.menubar.navigations", true);
pref("ctxextensions.submenu.menubar.nextHeading", true);
pref("ctxextensions.submenu.menubar.openSelectionAsURI", true);
pref("ctxextensions.submenu.menubar.outline", true);
pref("ctxextensions.submenu.menubar.prevHeading", true);
pref("ctxextensions.submenu.menubar.sendStr", true);
pref("ctxextensions.submenu.menubar.sendURI", true);
pref("ctxextensions.submenu.menubar.showAll", true);
pref("ctxextensions.submenu.menubar.showCites", true);
pref("ctxextensions.submenu.menubar.showComments", true);
pref("ctxextensions.submenu.menubar.showEvents", true);
pref("ctxextensions.submenu.menubar.showIDs", true);
pref("ctxextensions.submenu.menubar.showLinks", true);
pref("ctxextensions.submenu.menubar.showTitles", true);
pref("ctxextensions.submenu.menubar.styleSheets", true);
pref("ctxextensions.submenu.menubar.up", true);


pref("ctxextensions.new_window.force", false);
pref("ctxextensions.new_window.usetab", true);

pref("ctxextensions.new_window.help", true);
pref("ctxextensions.new_window.navigations", false);
pref("ctxextensions.new_window.openCiteForEdit", true);
pref("ctxextensions.new_window.openCiteForQuote", true);
pref("ctxextensions.new_window.openLongdesc", true);
pref("ctxextensions.new_window.openSelectionAsURI", true);
pref("ctxextensions.new_window.sendStr", true);
pref("ctxextensions.new_window.sendURI", true);
pref("ctxextensions.new_window.styleSheets", true);
pref("ctxextensions.new_window.up", false);


pref("ctxextensions.width.navigations", 24);
pref("ctxextensions.width.outline", 35);
pref("ctxextensions.width.customUserStyleEditor.title", 35);

pref("ctxextensions.defaultCharset", "UTF-8");

pref("ctxextensions.showall_enable.showCites", true);
pref("ctxextensions.showall_enable.showComments", true);
pref("ctxextensions.showall_enable.showEvents", true);
pref("ctxextensions.showall_enable.showIDs", true);
pref("ctxextensions.showall_enable.showLinks", false);
pref("ctxextensions.showall_enable.showTitles", true);

pref("ctxextensions.autoexec.customScripts", true);
pref("ctxextensions.autoexec.showCites", false);
pref("ctxextensions.autoexec.showComments", false);
pref("ctxextensions.autoexec.showEvents", false);
pref("ctxextensions.autoexec.showIDs", false);
pref("ctxextensions.autoexec.showLinks", false);
pref("ctxextensions.autoexec.showTitles", false);

pref("ctxextensions.popupToTop.width", 50);
pref("ctxextensions.popupToTop.height", 40);

// availability of keyboard shortcuts
pref("ctxextensions.shortcut.getLinks", true);
pref("ctxextensions.shortcut.goHeadings", true);
pref("ctxextensions.shortcut.advanceFocus_alphabet", true);
pref("ctxextensions.shortcut.advanceFocus_arrow", true);
pref("ctxextensions.shortcut.navigations", true);
pref("ctxextensions.shortcut.up", true);

// matching patterns to conjecture navigation items
pref("ctxextensions.regexp.navigations.appendix", "/\\bappendix\\b|\u30aa\u30de\u30b1|\u304a\u307e\u3051/");
pref("ctxextensions.regexp.navigations.contents", "/\\b(contents|toc|menu|site([ \\-]+)?map)\\b|\u30b3\u30f3\u30c6\u30f3\u30c4|\u76ee\u6b21|\u30e2\u30af\u30b8|\u3082\u304f\u3058|\u30b5\u30a4\u30c8\u30de\u30c3\u30d7/");
pref("ctxextensions.regexp.navigations.copyright", "/\\bcopyright\\b|\u8457\u4f5c\u6a29/");
pref("ctxextensions.regexp.navigations.glossary", "/\\bglossary\\b|\u7528\u8a9e\u96c6/");
pref("ctxextensions.regexp.navigations.help", "/\\bhelp\\b|\u30d8\u30eb\u30d7|\u554f\u3044?\u5408\u308f?\u305b/");
pref("ctxextensions.regexp.navigations.home", "/\\b(top|start|home)\\b|\u30c8\u30c3\u30d7|\u30db\u30fc\u30e0|\u30b9\u30bf\u30fc\u30c8|\u2191/");
pref("ctxextensions.regexp.navigations.index", "/\\bindex\\b|\u7d22\u5f15|\u30a4\u30f3\u30c7\u30c3\u30af\u30b9/");
pref("ctxextensions.regexp.navigations.next", "/\\b(next|forward|after|-?>)\\b|\u6b21|\u9032|\u5148|\u30c4\u30ae|\u3064\u304e\u3078|\u2192|\uff1e/");
pref("ctxextensions.regexp.navigations.prev", "/\\b(prev(ious)?|back|return|before|<-?)\\b|\u524d|\u623b|\u30e2\u30c9\u30eb|\u3082\u3069\u308b|\u307e\u3048\u3078|\u2190|\uff1c/");
pref("ctxextensions.regexp.navigations.search", "/\\b(search|find|seek)\\b|\u691c\u7d22|\u30b5\u30fc\u30c1/");


// style rules for "show XXX"
pref("ctxextensions.style.showCites", "display: inline !important;\nz-index: 200000 !important;\ntext-decoration: none !important;\nfont: small/1 monospace !important;\nbackground: white !important;\ncolor: blue !important;\nborder: outset thin !important;\npadding: 0.2em !important;\ntext-transform: none !important;\nletter-spacing: normal !important;\nword-spacing: normal !important;\nwhite-space: normal !important;\n");
pref("ctxextensions.style.showComments", "display: block !important;\nfont: medium/1.1 sans-serif !important;\nbackground: infobackground !important;\ncolor: infotext !important;\nborder: inset thin !important;\npadding: 0.5em !important;\ntext-transform: none !important;\nletter-spacing: normal !important;\nword-spacing: normal !important;\nwhite-space: -moz-pre-wrap !important;\n");
pref("ctxextensions.style.showEvents.label", "display: inline !important;\nz-index: 100000 !important;\ntext-decoration: none !important;\nfont: small/1 monospace !important;\nbackground: white !important;\ncolor: red !important;\nborder: none !important;\npadding: 0.2em !important;\ntext-transform: none !important;\nletter-spacing: normal !important;\nword-spacing: normal !important;\nwhite-space: normal !important;\n");
pref("ctxextensions.style.showEvents.value", "display: inline !important;\nz-index: 100000 !important;\ntext-decoration: none !important;\nfont: small/1 monospace !important;\nbackground: white !important;\ncolor: green !important;\nborder: none !important;\npadding: 0.2em !important;\ntext-transform: none !important;\nletter-spacing: normal !important;\nword-spacing: normal !important;\nwhite-space: normal !important;\n");
pref("ctxextensions.style.showIDs", "display: inline !important;\nz-index: 200000 !important;\ntext-decoration: none !important;\nfont: small/1 monospace !important;\nbackground: infobackground !important;\ncolor: infotext !important;\nborder: outset thin !important;\npadding: 0.2em !important;\ntext-transform: none !important;\nletter-spacing: normal !important;\nword-spacing: normal !important;\nwhite-space: normal !important;\n");
pref("ctxextensions.style.showLinks", "display: inline !important;\nz-index: 200000 !important;\ntext-decoration: none !important;\nfont: small/1 monospace !important;\nbackground: white !important;\ncolor: brown !important;\npadding: 0.2em !important;\ntext-transform: none !important;\nletter-spacing: normal !important;\nword-spacing: normal !important;\nwhite-space: normal !important;\n");
pref("ctxextensions.style.showTitles", "display: inline !important;\nz-index: 200000 !important;\ntext-decoration: none !important;\nfont: small/1 monospace !important;\nbackground: #EEFFFF !important;\ncolor: black !important;\nborder: outset thin !important;\npadding: 0.2em !important;\ntext-transform: none !important;\nletter-spacing: normal !important;\nword-spacing: normal !important;\nwhite-space: normal !important;\n");



//pref("ctxextensions.history.sendStr.****", "");
pref("ctxextensions.history.regexp.getLinks", "");

==> ctxextensions_3.1.2005012901.orig.tar.gz: ctxextensions-3.1.2005012901/chrome/content/ctxextensions/default/default.js <==
pref("ctxextensions.enable.debug_mode", false);
pref("ctxextensions.enable.expert_prefs", false);
pref("ctxextensions.enable.nsIXULTemplateBuilder", false);
pref("ctxextensions.enable.cite_as_href", false);
pref("ctxextensions.enable.popupToTop_TL", false);
pref("ctxextensions.enable.popupToTop_TR", false);
pref("ctxextensions.enable.popupToTop_BL", false);
pref("ctxextensions.enable.popupToTop_BR", false);
pref("ctxextensions.enable.popupToEnd_TL", false);
pref("ctxextensions.enable.popupToEnd_TR", false);
pref("ctxextensions.enable.popupToEnd_BL", false);
pref("ctxextensions.enable.popupToEnd_BR", false);
pref("ctxextensions.enable.getLinks_collectOnClick", false);
pref("ctxextensions.enable.navigations_advanced", false);
pref("ctxextensions.enable.navigations_collectLinks", false);
pref("ctxextensions.enable.navigations_submenu", true);

pref("ctxextensions.styleManager.userContentCSS_reload_alert", true);

pref("ctxextensions.scan_navigations_in_background.enable",   true);
pref("ctxextensions.scan_navigations_in_background.interval", 1000);
pref("ctxextensions.scan_outline_in_background.enable",       true);
pref("ctxextensions.scan_outline_in_background.interval",     1000);

pref("ctxextensions.JSPanel.page.number", 1);
pref("ctxextensions.JSPanel.page.last",   0);

pref("ctxextensions.override.datasource_path", "");
pref("ctxextensions.override.mailer.path", "");
pref("ctxextensions.override.mailer.options", "-to \"%to\" -subject \"%subject\"");
pref("ctxextensions.override.mailer.charset", "UTF-8");
pref("ctxextensions.override.mailer.webmail.enable", false);
pref("ctxextensions.override.mailer.webmail.usetab", true);
pref("ctxextensions.override.mailer.webmail.path", "http://foobar.com/?mailto=%to&subject=%subject");
pref("ctxextensions.override.source_viewer.path", "");
pref("ctxextensions.override.source_viewer.options", "%s");
pref("ctxextensions.override.CSSEditor.path", "");
pref("ctxextensions.override.CSSEditor.options", "%s");

// show in the context menu
pref("ctxextensions.show_item.context.bookmarks", true);
pref("ctxextensions.show_item.context.customScripts", true);
pref("ctxextensions.show_item.context.execApps", true);
pref("ctxextensions.show_item.context.extensions", true);
pref("ctxextensions.show_item.context.getLinks", true);
pref("ctxextensions.show_item.context.go", true);
pref("ctxextensions.show_item.context.help", false);
pref("ctxextensions.show_item.context.JSPanel", true);
pref("ctxextensions.show_item.context.navigations", true);
pref("ctxextensions.show_item.context.nextHeading", true);
pref("ctxextensions.show_item.context.openCiteForEdit", true);
pref("ctxextensions.show_item.context.openCiteForQuote", true);
pref("ctxextensions.show_item.context.openLongdesc", true);
pref("ctxextensions.show_item.context.openSelectionAsURI", true);
pref("ctxextensions.show_item.context.outline", true);
pref("ctxextensions.show_item.context.pref", false);
pref("ctxextensions.show_item.context.prevHeading", true);
pref("ctxextensions.show_item.context.sendStr", true);
pref("ctxextensions.show_item.context.sendURI", true);
pref("ctxextensions.show_item.context.showAll", true);
pref("ctxextensions.show_item.context.showCites", false);
pref("ctxextensions.show_item.context.showComments", false);
pref("ctxextensions.show_item.context.showEvents", false);
pref("ctxextensions.show_item.context.showIDs", false);
pref("ctxextensions.show_item.context.showLinks", false);
pref("ctxextensions.show_item.context.showTitles", false);
pref("ctxextensions.show_item.context.styleSheets", true);
pref("ctxextensions.show_item.context.up", true);

pref("ctxextensions.show_item.context.sep_exec", true);
pref("ctxextensions.show_item.context.sep_extensions", true);
pref("ctxextensions.show_item.context.sep_extensionsAbout", true);
pref("ctxextensions.show_item.context.sep_extensionsMisc", true);
pref("ctxextensions.show_item.context.sep_extensionsOpen", true);
pref("ctxextensions.show_item.context.sep_navigations", true);
pref("ctxextensions.show_item.context.sep_send", true);
pref("ctxextensions.show_item.context.sep_show", true);

// show in submenu
pref("ctxextensions.submenu.context.customScripts", false);
pref("ctxextensions.submenu.context.execApps", false);
pref("ctxextensions.submenu.context.getLinks", true);
pref("ctxextensions.submenu.context.help", true);
pref("ctxextensions.submenu.context.JSPanel", true);
pref("ctxextensions.submenu.context.navigations", false);
pref("ctxextensions.submenu.context.nextHeading", false);
pref("ctxextensions.submenu.context.openCiteForEdit", false);
pref("ctxextensions.submenu.context.openCiteForQuote", false);
pref("ctxextensions.submenu.context.openLongdesc", false);
pref("ctxextensions.submenu.context.openSelectionAsURI", false);
pref("ctxextensions.submenu.context.outline", false);
pref("ctxextensions.submenu.context.pref", true);
pref("ctxextensions.submenu.context.prevHeading", false);
pref("ctxextensions.submenu.context.sendStr", false);
pref("ctxextensions.submenu.context.sendURI", false);
pref("ctxextensions.submenu.context.showAll", true);
pref("ctxextensions.submenu.context.showCites", true);
pref("ctxextensions.submenu.context.showComments", true);
pref("ctxextensions.submenu.context.showEvents", true);
pref("ctxextensions.submenu.context.showIDs", true);
pref("ctxextensions.submenu.context.showLinks", true);
pref("ctxextensions.submenu.context.showTitles", true);
pref("ctxextensions.submenu.context.styleSheets", false);

pref("ctxextensions.submenu.menubar.customScripts", true);
pref("ctxextensions.submenu.menubar.execApps", true);
pref("ctxextensions.submenu.menubar.getLinks", true);
pref("ctxextensions.submenu.menubar.JSPanel", true);
pref("ctxextensions.submenu.menubar.navigations", true);
pref("ctxextensions.submenu.menubar.nextHeading", true);
pref("ctxextensions.submenu.menubar.openSelectionAsURI", true);
pref("ctxextensions.submenu.menubar.outline", true);
pref("ctxextensions.submenu.menubar.prevHeading", true);
pref("ctxextensions.submenu.menubar.sendStr", true);
pref("ctxextensions.submenu.menubar.sendURI", true);
pref("ctxextensions.submenu.menubar.showAll", true);
pref("ctxextensions.submenu.menubar.showCites", true);
pref("ctxextensions.submenu.menubar.showComments", true);
pref("ctxextensions.submenu.menubar.showEvents", true);
pref("ctxextensions.submenu.menubar.showIDs", true);
pref("ctxextensions.submenu.menubar.showLinks", true);
pref("ctxextensions.submenu.menubar.showTitles", true);
pref("ctxextensions.submenu.menubar.styleSheets", true);
pref("ctxextensions.submenu.menubar.up", true);


pref("ctxextensions.new_window.force", false);
pref("ctxextensions.new_window.usetab", true);

pref("ctxextensions.new_window.help", true);
pref("ctxextensions.new_window.navigations", false);
pref("ctxextensions.new_window.openCiteForEdit", true);
pref("ctxextensions.new_window.openCiteForQuote", true);
pref("ctxextensions.new_window.openLongdesc", true);
pref("ctxextensions.new_window.openSelectionAsURI", true);
pref("ctxextensions.new_window.sendStr", true);
pref("ctxextensions.new_window.sendURI", true);
pref("ctxextensions.new_window.styleSheets", true);
pref("ctxextensions.new_window.up", false);


pref("ctxextensions.width.navigations", 24);
pref("ctxextensions.width.outline", 35);
pref("ctxextensions.width.customUserStyleEditor.title", 35);

pref("ctxextensions.defaultCharset", "UTF-8");

pref("ctxextensions.showall_enable.showCites", true);
pref("ctxextensions.showall_enable.showComments", true);
pref("ctxextensions.showall_enable.showEvents", true);
pref("ctxextensions.showall_enable.showIDs", true);
pref("ctxextensions.showall_enable.showLinks", false);
pref("ctxextensions.showall_enable.showTitles", true);

pref("ctxextensions.autoexec.customScripts", true);
pref("ctxextensions.autoexec.showCites", false);
pref("ctxextensions.autoexec.showComments", false);
pref("ctxextensions.autoexec.showEvents", false);
pref("ctxextensions.autoexec.showIDs", false);
pref("ctxextensions.autoexec.showLinks", false);
pref("ctxextensions.autoexec.showTitles", false);

pref("ctxextensions.popupToTop.width", 50);
pref("ctxextensions.popupToTop.height", 40);

// availability of keyboard shortcuts
pref("ctxextensions.shortcut.getLinks", true);
pref("ctxextensions.shortcut.goHeadings", false);
pref("ctxextensions.shortcut.advanceFocus_alphabet", false);
pref("ctxextensions.shortcut.advanceFocus_arrow", false);
pref("ctxextensions.shortcut.navigations", false);
pref("ctxextensions.shortcut.up", true);

// matching patterns to conjecture navigation items
pref("ctxextensions.regexp.navigations.appendix", "/\\bappendix\\b|\u30aa\u30de\u30b1|\u304a\u307e\u3051/");
pref("ctxextensions.regexp.navigations.contents", "/\\b(contents|toc|menu|site([ \\-]+)?map)\\b|\u30b3\u30f3\u30c6\u30f3\u30c4|\u76ee\u6b21|\u30e2\u30af\u30b8|\u3082\u304f\u3058|\u30b5\u30a4\u30c8\u30de\u30c3\u30d7/");
pref("ctxextensions.regexp.navigations.copyright", "/\\bcopyright\\b|\u8457\u4f5c\u6a29/");
pref("ctxextensions.regexp.navigations.glossary", "/\\bglossary\\b|\u7528\u8a9e\u96c6/");
pref("ctxextensions.regexp.navigations.help", "/\\bhelp\\b|\u30d8\u30eb\u30d7|\u554f\u3044?\u5408\u308f?\u305b/");
pref("ctxextensions.regexp.navigations.home", "/\\b(top|start|home)\\b|\u30c8\u30c3\u30d7|\u30db\u30fc\u30e0|\u30b9\u30bf\u30fc\u30c8|\u2191/");
pref("ctxextensions.regexp.navigations.index", "/\\bindex\\b|\u7d22\u5f15|\u30a4\u30f3\u30c7\u30c3\u30af\u30b9/");
pref("ctxextensions.regexp.navigations.next", "/\\b(next|forward|after|-?>)\\b|\u6b21|\u9032|\u5148|\u30c4\u30ae|\u3064\u304e\u3078|\u2192|\uff1e/");
pref("ctxextensions.regexp.navigations.prev", "/\\b(prev(ious)?|back|return|before|<-?)\\b|\u524d|\u623b|\u30e2\u30c9\u30eb|\u3082\u3069\u308b|\u307e\u3048\u3078|\u2190|\uff1c/");
pref("ctxextensions.regexp.navigations.search", "/\\b(search|find|seek)\\b|\u691c\u7d22|\u30b5\u30fc\u30c1/");


// style rules for "show XXX"
pref("ctxextensions.style.showCites", "display: inline !important;\nz-index: 200000 !important;\ntext-decoration: none !important;\nfont: small/1 monospace !important;\nbackground: white !important;\ncolor: blue !important;\nborder: outset thin !important;\npadding: 0.2em !important;\ntext-transform: none !important;\nletter-spacing: normal !important;\nword-spacing: normal !important;\nwhite-space: normal !important;\n");
pref("ctxextensions.style.showComments", "display: block !important;\nfont: medium/1.1 sans-serif !important;\nbackground: infobackground !important;\ncolor: infotext !important;\nborder: inset thin !important;\npadding: 0.5em !important;\ntext-transform: none !important;\nletter-spacing: normal !important;\nword-spacing: normal !important;\nwhite-space: -moz-pre-wrap !important;\n");
pref("ctxextensions.style.showEvents.label", "display: inline !important;\nz-index: 100000 !important;\ntext-decoration: none !important;\nfont: small/1 monospace !important;\nbackground: white !important;\ncolor: red !important;\nborder: none !important;\npadding: 0.2em !important;\ntext-transform: none !important;\nletter-spacing: normal !important;\nword-spacing: normal !important;\nwhite-space: normal !important;\n");
pref("ctxextensions.style.showEvents.value", "display: inline !important;\nz-index: 100000 !important;\ntext-decoration: none !important;\nfont: small/1 monospace !important;\nbackground: white !important;\ncolor: green !important;\nborder: none !important;\npadding: 0.2em !important;\ntext-transform: none !important;\nletter-spacing: normal !important;\nword-spacing: normal !important;\nwhite-space: normal !important;\n");
pref("ctxextensions.style.showIDs", "display: inline !important;\nz-index: 200000 !important;\ntext-decoration: none !important;\nfont: small/1 monospace !important;\nbackground: infobackground !important;\ncolor: infotext !important;\nborder: outset thin !important;\npadding: 0.2em !important;\ntext-transform: none !important;\nletter-spacing: normal !important;\nword-spacing: normal !important;\nwhite-space: normal !important;\n");
pref("ctxextensions.style.showLinks", "display: inline !important;\nz-index: 200000 !important;\ntext-decoration: none !important;\nfont: small/1 monospace !important;\nbackground: white !important;\ncolor: brown !important;\npadding: 0.2em !important;\ntext-transform: none !important;\nletter-spacing: normal !important;\nword-spacing: normal !important;\nwhite-space: normal !important;\n");
pref("ctxextensions.style.showTitles", "display: inline !important;\nz-index: 200000 !important;\ntext-decoration: none !important;\nfont: small/1 monospace !important;\nbackground: #EEFFFF !important;\ncolor: black !important;\nborder: outset thin !important;\npadding: 0.2em !important;\ntext-transform: none !important;\nletter-spacing: normal !important;\nword-spacing: normal !important;\nwhite-space: normal !important;\n");



//pref("ctxextensions.history.sendStr.****", "");
pref("ctxextensions.history.regexp.getLinks", "");
